
#Background
##Background: bioinformatics
###Command Line/Terminal Tutorial
This workflow is written assuming that the user is using a computer running Mac OS X or Linux.  It is also possible to carry out many of the computational parts of this workflow in a Windows environment but getting these steps to work in Windows is outside the scope of this project. 

Some parts of this workflow require the user to provide text instructions for software programs by using a command line interface. While potentially intimidating to computer novices, the use of command line interfaces is sometimes necessary (_e.g._, some programs do not have graphical interfaces) and is also sometimes much more efficient. To access the command line on a Mac open the Terminal program (the default location for this program is in the "Utilities" folder under "Applications").

When this application is launched, a new window will appear. This is known as a "terminal" or a "terminal window". In the terminal window, you can interact with your computer without using a mouse. Many popular programs have a GUI (Graphical User Interface) but some programs used in this workflow will not. So, instead of double-clicking to make a program run, you will type a command in the terminal window. Throughout this tutorial, we will instruct you to type commands, but copying and pasting them (when possible) will reduce the occurrence of typos. We will walk you through how to run all of the programs required for this workflow, but you must first acquire a basic familiarity with how to interact with your computer through the terminal window. Below is a list of commands that will be required to use this workflow. There are many tutorials available to help you get started. 

For more information on operating in the terminal, check out
this informative video: [https://www.youtube.com/watch?v=zRZT4nQP3sE](https://www.youtube.com/watch?v=zRZT4nQP3sE)


And this interactive tutorial: [http://www.ee.surrey.ac.uk/Teaching/Unix/](http://www.ee.surrey.ac.uk/Teaching/Unix/)


###Summary of Unix/Linux commands and terms
$ **ls**			lists files and directories (folders).  If left as just "ls" this command will list the files and directories in your current location.  If a "path" is added afterwards (_e.g._, ls /usr) this command will list the files and directories in that location.

$ **cd**			use to change directories

$ **cd ..**    			use to move up one directory

$ **cd directory_name** 	use to move to that directory

$ **cd ~**			use to move to the home directory of the current user	

$ **grep "some pattern" file_name** displays lines that match the pattern (contained within the quotes) for which you are searching.   If a line contains the same character multiple times it will only be displayed once.

$ **grep –c “what you want to count” file_name** 	counts the number of lines containing a specific character or sequence of characters

$ **less file_name**					view a file, type q to exit

A few quick definitions:

_command line_ – the command line is where you type commands in a terminal window

_script_ – a computer program. Usually computer programs are called scripts when they perform relatively simple functions that are limited in scope. Scripts are typically only run from the command line

_directory_ – a folder

_compile_ - turning a human-readable file into a computer-executable program


###Software updates
Software packages are updated with varying frequencies. Some such updates will render the instructions offered here obsolete. When this occurs, you should consult with the software manual for help. An internet search with a description of the problem you are having may prove helpful. Another option is to email the software developer; many are remarkably responsive. As a last resort, consult with a colleague who is more comfortable with bioinformatics or computer programming.  Most software updates will require only minor modifications. For example, we might provide you with instructions to type:

    ./software_1.2.0/software.py
but a more recent release might necessitate:

    ./software_1.3.0/software.py


##Background: molecular biology and microbiology

This workflow assumes a basic knowledge of molecular biology and sterile technique (methods for carrying out lab experiments without contamination from living microorganisms). The starting point is the collection of microbes from a surface with a swab. We will cover the steps necessary to take a sample through plating, dilution streaking, overnight growth, creating a glycerol stock, 16S rDNA PCR, and preparation for Sanger sequencing to determine the identity of your bacterial or archaeal isolate.  

Throughout the "Isolation" section we refer frequently to "media" and "culture media". This is in reference to the type of substrate (sometimes liquid, sometimes a gel-like material such as agar) used to grow microbes in the lab. The choice of media will depend on the goals of the particular project. Some factors to consider when selecting media and conditions for growth include: 

1. What type of organism do you want to isolate?

2. Are there types of organisms (_e.g._, pathogens) that you would prefer not to isolate?  For example, swabbing people and growing samples on blood agar at 37°C can preferentially isolate human pathogens.
  
3. How much time is available for growth and isolation?
    + growth rates differ both between organisms (_e.g._, species 1 versus species 2) and also in different conditions for the same organisms (_e.g._, species 1 at 20°C  vs. 37°C)
    + for many microbes there is an "optimal growth temperature" (OGT - the temperature at which it grows best) but the OGT varies between species
    + you will be able to isolate a greater diversity of organisms if you allow a long time for slow-growing organisms to grow
   
4. What types of equipment are available to you?
     + if an organism grows most happily at 37°C, then you will need to have an incubator and shaker available at that temperature.

 For our previous work we used a rich media, lysogeny broth (LB), and growth at either room temperature (~25°C) or 37°C. For some basic information on media preparation and agar plates, we recommend the following resource: [http://teach.genetics.utah.edu/content/gsl/html/agar.html](http://teach.genetics.utah.edu/content/gsl/html/agar.html)
 
##Background: phylogeny and systematics.
In order to identify to which organism a 16S rDNA sequence belongs, as well as to provide an evolutionary context for your organism of interest, we recommend inferring a phylogenetic tree (see Section 7). Building such a phylogenetic tree is (relatively speaking) the easy part. Intelligent interpretation of the tree will require an investment of time, similar to the investment required to learn the basics of UNIX. Fortunately, there are a number of resources available for this purpose. We recommend [this online tutorial (http://evolution.berkeley.edu/evolibrary/article/phylogenetics_02)](http://evolution.berkeley.edu/evolibrary/article/phylogenetics_02) or \cite{Baldauf_2003} Here we provide a brief introduction to phylogenetic trees.

A phylogenetic tree is a diagram representing a model of evolutionary relationships.  Phylogenetic trees have three main components: taxa, branches, and nodes (Figure 2). These are defined below:

* ***Taxon***. An individual or grouping of individuals. This could be individual sequences, species, families, phyla, etc. For phylogenetic analyses, the taxa that are drawn at the tips of branches are sometimes referred to as "leaves" on the tree. 

* ***Branch***.  A representation of the evolution of a taxon over time (sometimes also known as an evolutionary lineage). There are three main types of branches in a tree. Terminal branches are those that lead to the tips or leaves in the tree. Internal branches connect branches to each other. And the root branch, also known as the root of the tree, is the branch that leads from the base of the tree to the first node in the tree. 

* ***Node***. These are the points where individual branches end. In the internal parts of a phylogenetic tree, single branches can "split" producing multiple descendant branches. The point at which the branches split is known as an internal node. If a branch ends at a taxon, the end point is known as a "terminal node". 

Some other information to know about trees: 

* ***Clade***. A group of organisms consisting of a single node and all the descendants of that node in a tree and nothing else.
* ***Bootstrapping***. A statistical method used to measure how well a node is supported by all the data being used. 
* ***Ingroup***. The group of taxa being studied.
* ***Outgroup***. A taxon that separated in an evolutionary tree prior to the existence of the most recent common ancestor of the ingroup.



