#Sanger Sequence Processing

The end product of Sanger sequencing is the production of sequences (reads) for each sample submitted. Upon receiving Sanger reads from a sequencing facility, typically as .abi files via email, it is necessary to do some pre-processing before they can be analyzed. These steps include quality trimming the reads, reverse complementing the reverse sequence, aligning the reads, generating a consensus sequence, and converting to FASTA format. There are very limited options for free software that allow the user to perform these steps. 

In this workflow we recommend using an automated pipeline available at the Ribosomal Database Project \cite{Cole_2013} if working with a large number of sequences. This pipeline only provides a rough view, since it doesn't orient or align the reads, it simply quality trims them and outputs the data in a format that can be fed directly to the BLAST program at NCBI \cite{Altschul_1990}. This will at least give an idea of which genera, and sometimes which species, to which each sequence can be classified. We then recommend processing samples of interest using SeqTrace \cite{stucky2012seqtrace} which allows the user to see the traces (graphical representation of reads), process the sequences manually, and a get a longer, more accurate sequence for analysis.

We have also created a script that will perform the same steps as SeqTrace automatically, but does not allow you to adjust any of the parameters. The choice of our script (easy, little control) versus SeqTrace (more complex, more control) will depend on the user and the project.

##RDP Sanger pipeline

_(recommended as a starting place, or when working with many sequences)_

The RDP Sanger analysis pipeline can be found here [https://rdp.cme.msu.edu/login/pipeline/libSummary](https://rdp.cme.msu.edu/login/pipeline/libSummary). 

This pipeline allows you to upload one zipped folder containing multiple .abi traces. It cleans and processes the sequences and generates a FASTA file of the processed sequences; which can then be uploaded to BLAST and analyzed. This allows you to quickly screen your samples before running the files through the more time consuming SeqTrace analysis which will reverse complement and align the reads to generate a consensus sequence.

After signing in to RDP, you will be on the "Library Run Summary" page. Click on the "Create New Run" tab near the top of the page. Select the appropriate 16S rRNA gene (Archaea or Bacteria depending on your sample) name your library and choose a library name abbreviation and select any vector (this pipeline assumes cloned PCR fragments but will work fine regardless of what you select here). Select the "Upload the data without well mapping" button at the bottom of the page. You will now be directed to the "Data Loader" page, choose a zipped folder containing the .abi traces you wish to analyze and click "Load Data". To create the folder, put all of the .abi traces you are working with into a folder, right click on the folder and select Compress “folder name”. If you downloaded the files as a group from your sequencing facility, they may already be in a zipped folder.

When the pipeline is finished, you will be directed to click a link that will open a new window containing the library run stats. Select the "Download Raw Sequence" button. Navigate to [http://blast.ncbi.nlm.nih.gov/Blast.cgi?PROGRAM=blastn&PAGE_TYPE=BlastSearch&LINK_LOC=blasthome](http://blast.ncbi.nlm.nih.gov/Blast.cgi?PROGRAM=blastn&PAGE_TYPE=BlastSearch&LINK_LOC=blasthome) and select the "Choose File" button underneath the area for the FASTA sequence. Select the file you just downloaded from the library run stats page. We recommend checking the box to exclude Uncultured/environmental sample sequences then click "BLAST". If you are working with a large number of FASTA sequences, it may take a few minutes. When the BLAST search is complete, you can cycle through the results using the pull down menu to the right of the "Results for:" heading. 

##SeqTrace

_We recommend using SeqTrace first if only working with a couple of sequences. When working with a large batch it might be easier to do a preliminary screening of the sequences using the RDP Sanger pipeline above and only using SeqTrace for sequences of interest._

Download the program from
[https://code.google.com/p/seqtrace/downloads/list](https://code.google.com/p/seqtrace/downloads/list)

Installation directions
[https://code.google.com/p/seqtrace/wiki/Installation](https://code.google.com/p/seqtrace/wiki/Installation)

Installing and running SeqTrace on a PC is simple; installing it on a Mac requires a few more steps than for a PC. The installation guide offers two options for installing SeqTrace on a Mac; we recommend running SeqTrace with native GTK+.

To install SeqTrace on a Mac, you will need to download the PyGTK package from OSX. 
[http://sourceforge.net/projects/macpkg/files/PyGTK/2.24.0/PyGTK.pkg/download](http://sourceforge.net/projects/macpkg/files/PyGTK/2.24.0/PyGTK.pkg/download)

Currently, SeqTrace depends on Python version 2.x. Confirm that you have Python version 2.x. You can do this by typing:

    python --version

You should see something that looks like "Python 2.6.9" If you see Python 3.x, seek outside help to run an earlier version.

[http://www.python.org/downloads/](http://www.python.org/downloads/)

After downloading and unpacking the program, SeqTrace is ready for use. SeqTrace must be launched from a Terminal window. For a refresher or introduction to the Terminal, see Section 2.1. Move SeqTrace to your Applications folder. 

Open a Terminal window and copy/paste or type:

    /Applications/seqtrace-0.9.0/seqtrace.py

This syntax will only work if the SeqTrace folder’s name is seqtrace-0.9.0, if you saved it under a different name you will need to replace seqtrace-0.9.0 with the name of that folder.

This will launch SeqTrace from the terminal in a Python shell; you will need to keep the terminal window open while you are using the program. 

SeqTrace provides excellent instructions for using the program at [https://code.google.com/p/seqtrace/wiki/WorkingWithProjects](https://code.google.com/p/seqtrace/wiki/WorkingWithProjects)

###Edit and Create a Consensus Sequence with SeqTrace
For this workflow we have found that the following is the simplest way to edit and create a consensus sequence from forward and reverse reads in SeqTrace. 

1. Create a new project (File > New Project). Add your forward and reverse primer sequences here; we used 27F (AGAGTTTGATCMTGGCTCAG) 
and 1391R (GACGGGCGGTGTGTRCA) and click "OK".
2. To add files, go to "Traces" and click on "Add trace files", then select the reads (.abi files) you want to work with. 
3. The program is able to recognize forward and reverse reads from information in the file name if they are properly formatted.
 + Go to "Traces" and click on "Find" and mark forward/reverse. The default setting looks for \_F for forward and \_R for reverse. This can be edited in the Project settings (you can pull it up by clicking on the picture of the tool at the top of the page) and changing the search strings under trace settings. For an example, see Figure 3.
 + If the program is able to recognize the forward/reverse reads it will place an orange left pointing arrow in front of reverse reads and a blue right pointing arrow in front of forward reads. This step is not necessary to get a consensus sequence, it just makes organizing the reads easier. 
4. Pull up the "Project Settings" by clicking on the picture of tool at the top of the page. Click on the "Sequence Processing" tab and under "Sequence trimming," unclick the Automatically trim sequence ends button. You should also decrease the Min. confidence score under "Consensus" settings. The default option is 30, which represents 99.9% accuracy. For many reads this will be too stringent and will not allow you to get enough overlap to create a consensus sequence. A minimum confidence score between 15 and 25 is normally okay but tuning may be required depending on your read quality. For an example, see Figure 4.
5. Group your forward and reverse reads by highlighting both of them and clicking "Group selected forward/reverse files" (under "Traces")
6. Under "Sequences" go to "Generate Finished Sequences" and click on "for all trace files". (you will need to redo this every time you change the project settings).
7. To view your consensus sequence, click on the read pair group and then click on the magnifying glass at the top of the page. You should see something like Figure 5.
8. The "Trace View" shows the quality scores, the chromatogram (trace) display, and the raw base calls from both the forward and reverse reads, as well as the consensus sequence. The consensus sequence is the middle list of nucleotides. If the program is giving you a string of Ns where your forward and reverse reads do not overlap, you need to decrease the Min. confidence score.
9. To export the consensus from the trace view, go to "Sequence", hover on "Export Sequences", and select "Export Sequences from Selected Trace Files". This will create a file containing the consensus sequence, which can then be used for analysis such as searching for closely related sequences using the BLAST program \cite{Altschul_1990} which can be used to identify the organism.

##Custom Script to Create a Consensus Sequence (merge\_sanger\_16s.pl)

_This custom script is for users who prefer to quickly trim and align their sequences. It is to be used in place of SeqTrace, with or without having pre-screened samples using the RDP Sanger pipeline described above._

###Download/Install
1. Create a new folder called "Sanger_seq" on your Desktop
2. Download the zip file, containing three scripts (merge\_sanger\_16s.pl, cleanup.pl and subsample\_reads.pl) from \cite{47b41cbb-81bb-44cb-8430-1218ddad365c}
3. Open the zip file and move the merge\_sanger\_16s.pl file to the new "Sanger_seq" folder

###MUSCLE
In order to run this script you will need to download MUSCLE \cite{Edgar_2004} from here: [http://www.drive5.com/muscle/downloads.htm](http://www.drive5.com/muscle/downloads.htm). Uncompress and open the MUSCLE directory, and record the full path and name of the executable file (_e.g._ muscle3.8.31\_i86darwin64) for later use.

###Convert Files from .abi to .fastq

To run the merge\_sanger\_16s.pl script, you will first need to convert your read files from .abi to .fastq

This can be done at 
[http://sequenceconversion.bugaco.com/converter/biology/sequences/](http://sequenceconversion.bugaco.com/converter/biology/sequences/)

Use the drop down menus to set it to convert .abi files to .fastq. Upload a file and convert it. The converted file will save to your downloads folder under the name "sample.fastq". If you are working with a lot of reads, we recommend immediately renaming the files to match the original .abi file name to avoid confusion.

###Edit and Create a Consensus Sequence
Once all of your files are in .fastq format, move all of them to the "Sanger\_seq' folder in which you saved the merge\_sanger\_16s.pl script. Use the terminal to navigate to within this folder by typing:

    cd /Desktop/Sanger_seq

Then, to run the script, type:

    perl merge_sanger_16s.pl <muscle_path> <file1.fastq> <file2.fastq>
    
muscle\_path refers to the full path and file name that were recorded earlier (_e.g._, /Users/username/Downloads/muscle\_download/muscle/muscle3.8.31_i86darwin64 )

The script will return one of 2 messages:

1. "Found N conflicting case(s) during merging of X residues" 
2. "Not enough data to overlap confidently" 

In the first case, the merging happened, however there may be some conflicting bases. The fewer the better. It can be an indication of how confident the user should be with the results. Since this is a very crude method, it should be noted that there is no complex algorithm behind the merge. There is a simple comparison for which we keep the base that had the highest quality score.

In the second outcome, the sequences were trimmed too much when doing the quality-trimming. The length of both sequences end to end was smaller than the fragment length that we are looking for. This is an indication of poor quality sequence and most users should not proceed (others can lower the quality threshold set by the script).

The newly merged file will be saved as file1\_merged.fasta and can be uploaded to BLAST for identification (see Section 6.1).
