#Genome Sequencing
##Library Preparation
The first choice in library preparation is whether to do the library prep yourself or to have the library made by your sequencing provider. The economics of this decision are usually dependent on the number of samples involved. For example, an Illumina TruSeq library prep kit costs around $2600 for 48 samples. That's far cheaper than the $150 to $300 that a typical sequencing provider would charge per sample. However, if you're only preparing a couple of samples there's no reason to buy an entire kit. The requisite time and ancillary consumables and equipment must also be taken into account (see Table 1). Most sequencing facilities offer library preparation services.

##Kit Options
Whether you chose to make libraries yourself or use a service provider, the next major choice is of the type of kit. The two most popular choices with Illumina kits are the Nextera transposase-based kits or the TruSeq kits (with or without PCR). These kits are available from Illumina, but there are also comparable options from other vendors (_e.g._ New England Biolabs and Kapa Bioscience).  In addition, there have been cost-saving modifications to the Illumina kits, for example \cite{Baym_2015}. The pros and cons of each type of kit are listed below:

+ TruSeq (our recommendation): _Pro_ – The PCR-free protocol minimizes library bias by using mechanical instead of enzymatic DNA fragmentation, and the elimination of PCR results in better assemblies. _Con_ – requires a large amount of DNA (at least 1 μg for PCR-free).  There is also now a TruSeq LT kit which only requires 100ng of DNA and a reduced number of PCR cycles. This may provide a middle option between PCR-free TruSeq and Nextera.
+ Nextera: _Pro_ – It allows for very low amounts of input DNA, down to 1ng in the case of the Nextera XT kit. _Con_ – the transposase has an insertion bias and the extensive PCR required for low input samples will also impact the final assembly \cite{Aird_2011}.

When growing bacteria in culture as described in this workflow, it should almost always be possible to get enough DNA to use PCR-free TruSeq and therefore minimize library preparation biases in the genome assembly.

##Choosing an insert size
In our lab, with paired-end 300bp (PE300) reads on the Illumina MiSeq, we target a DNA fragment size (including adapters) of 600-900bp. The high end of the range is constrained by the maximum length of a DNA molecule that can be amplified on the Illumina MiSeq. The low end of the range is defined by the smallest fragment size that will not produce overlapping reads. Ideally, you would sequence only at the high end of the range because longer insert sizes aid in better genome assembly. However, the range is typically expanded to ensure that enough DNA is available for sequencing. Different sequencing facilities have different opinions on this topic and it is worth having a discussion with your sequencing facility's point of contact before making any libraries. It is very important that all samples have similar insert sizes if multiplexing as described below.

##Multiplexing
Coverage (also known as read depth) is the average number of reads representing a given nucleotide. It is a function of the number and size of genomes pooled onto a run and the number and length of reads. The optimal amount of coverage depends on the read length, the assembler being used, and other factors. The capacity of an Illumina MiSeq with PE300 reads is around 15 Gigabases (Gb), which would result in a coverage of 4300X for a typical bacterium with a 3.5 Mb genome. On the HiSeq with PE125bp reads, this would be over 14,000X coverage. Currently, the recommended coverage for a bacterial genome assembly is 20-200X depending on the choice of assembler. Therefore, sequencing a single bacterial genome on a full MiSeq or HiSeq run is a significant waste of money and reagents. Furthermore, some current genome assembly algorithms do not perform well given an excess of data, and require down-sampling (_i.e_., throwing away data, Section 8.6) to achieve the recommended coverage for assembly. We typically multiplex 10-48 genomes on a PE300 MiSeq run and many more on a HiSeq run. If using a kit for library prep, multiplexing is quite straightforward since there are a number of barcoded adapters that come with the kit. We recommend having the sequencing facility demultiplex the samples, as this only requires a list of the barcodes used.

##Collaborate
As described above, current Illumina sequencing systems have much greater capacity than is needed for sequencing a single genome. This means it can be generally beneficial to combine many samples into a single run of a machine. Unfortunately, our experience has been that sequencing facilities will typically not help in the coordination of such pooling of samples (we assume because they do not want to oversee the pooling or deal with the associated accounting hassles). Therefore, it is typically up to the users to carry out such coordination. Though this can sometimes be complicated, it is generally worthwhile, since one can pool together many genomes or metagenomes into a single run of a system and still get enough data for each project, thus making the sequencing cost per project significantly lower. For this to work well, one needs to coordinate the use of barcodes to tag each sample, coordinate the pooling, and have available the informatics required to "demultiplex" samples from each other. 

##Downsampling
For Illumina data assembled using this workflow, we recommend a coverage of between 20X and 200X. See our more detailed discussion in Section 9.1.3 "Interpretation of A5-miseq stats". If you have coverage significantly higher than 200X and wish to downsample your data, we have written a script (sub\_sample\_reads) for this purpose. Downsampling should not be necessary if following the assembly instructions in this workflow. If downsampling, you will first need to calculate how many reads you want the script to sample. We recommend determining how many reads would be equivalent to 100X coverage (divide the genome size by the average read length and multiply by 100). You can download the script from the zipped script file found on Figshare \cite{47b41cbb-81bb-44cb-8430-1218ddad365c}. Create a new directory containing the script (sub\_sample\_reads) and the reads you wish to downsample. 
    
To downsample the data, navigate to the directory you just created (in the terminal) and use the following command

    ./subsample_reads.pl <file1> <file2> <#_reads_to_keep> <output_file_name>  
for example   

    ./subsample_reads.pl test_1.fq test_2.fq 250 my_reads.fastq  
    
For further directions and documentation you can view the script [on github](https://github.com/gjospin/scripts/blob/master/subsample_reads.pl)
